@@ -10,11 +10,11 @@
 'use strict'
 
 import { schema } from 'normalizr'
-import lodash from 'lodash'
+import _ from 'lodash'
 
 export const createResourcesSchema = (attribute, uniqueKey) => {
   // to support multi cluster, use ${name}-${uniqueKey} as unique id
   return new schema.Entity('items', {},
-    { idAttribute: value => `${lodash.get(value, attribute)}-${lodash.get(value, uniqueKey)}` }
+    { idAttribute: value => `${_.get(value, attribute)}-${_.get(value, uniqueKey)}` }
   )
 }
