@@ -46,14 +46,6 @@ class RemoveResourceModal extends React.Component {
     })
     const children = []
     // Create object specifying Application resources that can be deleted
-    _.map(data.deployables, (curr, idx) => {
-      children.push({
-        id: idx + '-deployable-' + curr.metadata.name,
-        selfLink: curr.metadata.selfLink,
-        label: curr.metadata.name + ' [Deployable]',
-        selected: true
-      })
-    })
     _.map(placementBindings, (curr, idx) => {
       if (curr.name) {
         children.push({
@@ -67,21 +59,13 @@ class RemoveResourceModal extends React.Component {
     _.map(placementRules, (curr, idx) => {
       if (curr.name) {
         children.push({
-          id: idx + '-placementPolicy-' + curr.name,
+          id: idx + '-placementRule-' + curr.name,
           selfLink: curr.selfLink,
-          label: curr.name + ' [PlacementPolicy]',
+          label: curr.name + ' [PlacementRule]',
           selected: true
         })
       }
     })
-    _.map(data.applicationRelationships, (curr, idx) => {
-      children.push({
-        id: idx + '-appRelationship-' + curr.metadata.name,
-        selfLink: curr.metadata.selfLink,
-        label: curr.metadata.name + ' [ApplicationRelationship]',
-        selected: true
-      })
-    })
     if (children.length > 0 && this.state.selected.length < 1) {
       this.setState({selected: children})
     }
@@ -112,13 +96,11 @@ class RemoveResourceModal extends React.Component {
 
   modalBody = (data, label, locale) => {
     switch (label.label) {
-    case 'modal.remove-hcmapplication.label':
     case 'modal.remove-hcmcompliance.label':
-    case 'modal.remove-hcmpolicypolicy.label':
       return this.state.selected.length > 0
         ? <div className='remove-app-modal-content' >
           <div className='remove-app-modal-content-text' >
-            {msgs.get('modal.remove.application.confirm', [data.name || data.Name || data.metadata.name], locale)}
+            {msgs.get('modal.remove.policy.confirm', [data.name || data.Name || data.metadata.name], locale)}
           </div>
           <div>
             {this.state.selected.map((child) => {
@@ -183,7 +165,6 @@ RemoveResourceModal.propTypes = {
     deployables: PropTypes.object,
     name: PropTypes.string,
     namespace: PropTypes.string,
-    applicationRelationships: PropTypes.oneOfType([PropTypes.object, PropTypes.array]),
     selected: PropTypes.array,
   }),
   handleClose: PropTypes.func,
