@@ -154,21 +154,11 @@ export const staticResourceData = {
         'resourceKey': 'metadata.namespace',
         'msgKey': 'table.header.namespace'
       },
-      {
-        'key': 'replicas',
-        'resourceKey': 'clusterReplicas',
-        'msgKey': 'table.header.replicas'
-      },
       {
         'key': 'clusterSelector',
         'resourceKey': 'clusterLabels',
         'msgKey': 'table.header.cluster.selector'
       },
-      {
-        'key': 'resourceSelector',
-        'resourceKey': 'resourceSelector',
-        'msgKey': 'table.header.resource.selector'
-      },
       {
         'key': 'decisions',
         'resourceKey': 'status',
@@ -1067,8 +1057,6 @@ export const items = [
             }
           ]
         },
-        'clusterReplicas': null,
-        'resourceSelector': {},
         'status': {
           'decisions': [
             {
@@ -1503,7 +1491,7 @@ export const items = [
 
 export const resourceType = {
   'name': 'HCMCompliance',
-  'list': 'HCMComplianceList'
+  'query': 'ALL_POLICIES'
 }
 
 export const findingsData = [
