@@ -14,17 +14,15 @@ const allpolicy = require('./AllPolicyPage')
 module.exports = {
   elements: {
     spinner: '.patternfly-spinner',
-    table: '.bx--data-table-v2',
-    tableExpandBtn: '.bx--table-expand-v2__button:nth-of-type(1)',
-    expandTable: '.bx--expandable-row-v2:nth-of-type(2)',
+    table: '.pf-c-table',
     createPolicyButton: '#create-policy',
     cancelCreatePolicyButton: '#cancel-button-portal-id',
     submitCreatePolicyButton: '#create-button-portal-id',
     yamlMonacoEditor: '.monaco-editor',
-    searchInput: '#search',
-    searchInputClear: '#search ~ .bx--search-close',
+    searchPatternFlyInput: '.pf-c-search-input__text-input',
+    searchPatternFlyInputClear: '.pattern-fly-table-group .pf-c-search-input .pf-c-search-input__clear .pf-c-button',
+    PatternFlyTabEmptyState: '.pattern-fly-table-group .pattern-fly-table .pf-c-empty-state__content',
     overflowButton: '.bx--overflow-menu:nth-of-type(1)',
-    deleteButton: '.bx--overflow-menu-options__option--danger',
     confirmDeleteButton: '.bx--btn--danger--primary',
     noResource: '.no-resource',
     policyStatus: '#complianceStatus-module-id',
@@ -42,10 +40,10 @@ module.exports = {
     categoriesDropdownBox: '.creation-view-controls-container > div > div:nth-child(6) > div.bx--multi-select.bx--list-box > div.bx--list-box__menu',
     controlsDropdown: '.creation-view-controls-container > div > div:nth-child(7) > div.bx--multi-select.bx--list-box',
     controlsDropdownBox: '.creation-view-controls-container > div > div:nth-child(7) > div.bx--multi-select.bx--list-box > div.bx--list-box__menu',
-    summaryCollapse: 'button.collapse > span.collapse-button',
-    summaryInfoContainer: 'div.module-grc-cards > div.card-container-container',
-    summaryDropdown: 'div.module-grc-cards > div:nth-child(1) > div:nth-child(2) > div > div:nth-child(1)',
-    summaryDropdownBox: 'div.module-grc-cards > div:nth-child(1) > div:nth-child(2) > div > div:nth-child(2)',
+    summaryCollapse: 'button#summary-toggle > span.pf-c-accordion__toggle-icon',
+    summaryInfoContainer: 'div.module-grc-cards > dl > dd.grc-cards-container',
+    summaryDropdown: 'div.module-grc-cards > dl > div.header-options > .pf-c-dropdown > button#grc-cards-toggle',
+    summaryDropdownBox: 'div.module-grc-cards > dl > div.header-options > .pf-c-dropdown > ul',
     filterClear: '.resource-filter-bar > span.button',
   },
   commands: [{
@@ -53,11 +51,12 @@ module.exports = {
     searchPolicy,
     deletePolicy,
     checkStatus,
-    setSearchValue,
-    clearSearchValue,
+    setPatternFlySearchValue,
+    clearPatternFlySearchValue,
     log,
     enforcePolicy,
     informPolicy,
+    testPolicyStatusTabSearching,
     tryEnable,
     tryDisable,
     clickButtonOnOverflowModal,
@@ -86,14 +85,14 @@ function noResourceCheck(path='', exists=false) {
 */
 function clickButtonOnOverflowModal(name, nameTarget, overflowPosition, actionName, actionPosition, modalName, clickButtonName){
   this.log(`modal ${modalName} -- ${actionName} policy ${name} button ${clickButtonName}`)
-  this.waitForElementVisible('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra')
-  this.expect.element(`.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(2) > ${nameTarget}`).text.to.equal(name)
-  this.waitForElementVisible(`table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(${overflowPosition})`)
-  this.click(`table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(${overflowPosition}) > div > svg`)
-  this.waitForElementVisible('ul.bx--overflow-menu-options.bx--overflow-menu--flip.bx--overflow-menu-options--open')
-  this.waitForElementVisible(`ul.bx--overflow-menu-options.bx--overflow-menu--flip.bx--overflow-menu-options--open > li:nth-child(${actionPosition})`)
-  this.expect.element(`ul.bx--overflow-menu-options.bx--overflow-menu--flip.bx--overflow-menu-options--open > li:nth-child(${actionPosition}) > button`).text.to.equal(actionName)
-  this.click(`ul.bx--overflow-menu-options.bx--overflow-menu--flip.bx--overflow-menu-options--open > li:nth-child(${actionPosition}) > button`)
+  this.waitForElementVisible('.pf-c-table')
+  this.expect.element(`.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(1) > ${nameTarget}`).text.to.equal(name)
+  this.waitForElementVisible(`.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(${overflowPosition})`)
+  this.click(`.pf-c-table > tbody > tr:nth-child(1) > td:nth-child(${overflowPosition}) > div > button`)
+  this.waitForElementVisible('.pf-c-dropdown__menu')
+  this.waitForElementVisible(`.pf-c-dropdown__menu > li:nth-child(${actionPosition})`)
+  this.expect.element(`.pf-c-dropdown__menu > li:nth-child(${actionPosition}) > button`).text.to.equal(actionName)
+  this.click(`.pf-c-dropdown__menu > li:nth-child(${actionPosition}) > button`)
   this.waitForElementVisible(modalName)
   this.waitForElementVisible(`${modalName} > div > .bx--modal-footer > ${clickButtonName}`)
   this.click(`${modalName} > div > .bx--modal-footer > ${clickButtonName}`)
@@ -130,9 +129,9 @@ function createPolicy(browser, name, yaml, time, filename) {
   this.click('@submitCreatePolicyButton')
   //verify placementrule + placementbinding
   this.expect.element('@table').to.be.present
-  this.waitForElementVisible('@searchInput')
-  this.setSearchValue(name)
-  this.click('tbody>tr>td>a')
+  this.waitForElementVisible('@searchPatternFlyInput')
+  this.setPatternFlySearchValue(name)
+  this.click('tbody tr > *:first-child > a')
   this.waitForElementNotPresent('@spinner')
   this.expect.element('.bx--detail-page-header-title').text.to.equal(name)
   this.expect.element('.section-title:nth-of-type(1)').text.to.equal('Policy details')
@@ -160,51 +159,53 @@ function enforcePolicy(name){
   this.log(`Enforcing policy: ${name}`)
   //verify table/menu exist
   this.waitForElementVisible('body')
-  this.waitForElementVisible('@searchInput')
-  this.setSearchValue(name)
+  this.waitForElementVisible('@searchPatternFlyInput')
+  this.setPatternFlySearchValue(name)
   //verify cancel button (.bx--btn.bx--btn--tertiary) on enforce policy modal and return to main page
   this.clickButtonOnOverflowModal(name, 'a', 9, 'Enforce', 3, '#enforce-resource-modal', '.bx--btn.bx--btn--tertiary')
   //re-entry overflow menu then click enforce policy button (.bx--btn.bx--btn--danger--primary)
   this.clickButtonOnOverflowModal(name, 'a', 9, 'Enforce', 3, '#enforce-resource-modal', '.bx--btn.bx--btn--danger--primary')
-  this.waitForElementVisible('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra')
-  this.expect.element('.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(4)').text.to.equal('enforce')
-  this.clearSearchValue()
+  this.waitForElementVisible('.pf-c-table')
+  this.expect.element('.pf-c-table> tbody > tr:nth-child(1) > td:nth-child(3)').text.to.equal('enforce')
+  this.clearPatternFlySearchValue()
 }
 
 function informPolicy(name){
   this.log(`Informing policy: ${name}`)
   //verify table/menu exist
   this.waitForElementVisible('body')
-  this.waitForElementVisible('@searchInput')
-  this.setSearchValue(name)
+  this.waitForElementVisible('@searchPatternFlyInput')
+  this.setPatternFlySearchValue(name)
   //verify cancel button (.bx--btn.bx--btn--secondary) on inform policy modal and return to main page
   this.clickButtonOnOverflowModal(name, 'a', 9, 'Inform', 3, '#inform-resource-modal', '.bx--btn.bx--btn--secondary')
   //re-entry overflow menu then click inform policy button (.bx--btn.bx--btn--primary)
   this.clickButtonOnOverflowModal(name, 'a', 9, 'Inform', 3, '#inform-resource-modal', '.bx--btn.bx--btn--primary')
-  this.waitForElementVisible('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra')
-  this.waitForElementVisible('.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(4)')
-  this.expect.element('.bx--data-table-v2.resource-table.bx--data-table-v2--zebra > tbody > tr:nth-child(1) > td:nth-child(4)').text.to.equal('inform')
-  this.clearSearchValue()
+  this.waitForElementVisible('.pf-c-table')
+  this.waitForElementVisible('.pf-c-table> tbody > tr:nth-child(1) > td:nth-child(3)')
+  this.expect.element('.pf-c-table> tbody > tr:nth-child(1) > td:nth-child(3)').text.to.equal('inform')
+  this.clearPatternFlySearchValue()
 }
 
 function checkStatus(name, violationExpected, violationText) {
   this.log(`Checking policy: ${name} violationExpected: ${violationExpected}`)
-  this.waitForElementVisible('@searchInput')
-  this.setSearchValue(name)
-  this.expect.elements('tbody>tr>td>a').count.to.equal(1).before(2000)
+  this.waitForElementVisible('@searchPatternFlyInput')
+  this.setPatternFlySearchValue(name)
+  this.expect.elements('tbody tr > *:first-child > a').count.to.equal(1).before(2000)
   // wait for yellow triangle to disappear
-  this.waitForElementNotPresent('css selector','#table-container .violationCell svg[fill=\'#f0ab00\']')
+  this.waitForElementNotPresent('css selector','.pf-c-table .violationCell svg[fill=\'#f0ab00\']')
   if (violationExpected) {
     // should show red not compliant
-    this.waitForElementPresent('css selector', '#table-container .violationCell svg[fill=\'#c9190b\']')
+    this.waitForElementPresent('css selector', '.pf-c-table .violationCell svg[fill=\'#c9190b\']')
   } else {
     // should show green compliant
-    this.waitForElementPresent('css selector', '#table-container .violationCell svg[fill=\'#467f40\']')
+    this.waitForElementPresent('css selector', '.pf-c-table .violationCell svg[fill=\'#467f40\']')
   }
-  this.click('tbody>tr>td>a')
+  this.click('tbody tr > *:first-child > a')
   this.waitForElementPresent('#status-tab')
   this.click('#status-tab')
   this.waitForElementPresent('.policy-status-view')
+  this.expect.element('tbody tr > *:first-child > a').to.have.attribute('href').that.matches(/.*\/multicloud\/clusters\/[a-z0-9-]+\/overview$/)
+  this.testPolicyStatusTabSearching()
   this.log('Checking policy status by templates')
   this.waitForElementPresent('#policy-status-templates').click('#policy-status-templates')
   this.waitForElementPresent('.policy-status-by-templates-table')
@@ -261,43 +262,60 @@ function checkStatus(name, violationExpected, violationText) {
 }
 
 function searchPolicy(name, expectToDisplay) {
-  this.waitForElementVisible('@searchInput')
-  this.clearSearchValue()
-  this.expect.elements('tbody>tr').count.not.to.equal(0)
-  this.click('@searchInput').setSearchValue(name)
-  if (expectToDisplay) {
-    this.expect.elements('tbody>tr').count.to.equal(1)
-    this.expect.element('tbody>tr').to.have.attribute('data-row-name').equals(name)
-  } else {
-    this.waitForElementNotPresent('tbody>tr')
+  this.setPatternFlySearchValue(name)
+  if(expectToDisplay){
+    this.expect.element('tbody tr > *:first-child > a').text.to.equal(name)
+  } else{
+    this.waitForElementNotPresent('tbody tr > *:first-child > a')
   }
 }
 
 function deletePolicy(name){
   this.log(`Deleting policy: ${name}`)
   this.waitForElementVisible('body')
-  this.waitForElementVisible('@searchInput')
-  this.searchPolicy(name, true)
+  this.waitForElementVisible('@searchPatternFlyInput')
+  this.setPatternFlySearchValue(name)
   //verify cancel button (.bx--btn.bx--btn--tertiary) on delete policy modal and return to main page
-  this.clickButtonOnOverflowModal(name, 'a', 9, 'Remove', 4, '#remove-resource-modal', '.bx--btn.bx--btn--tertiary')
+  this.clickButtonOnOverflowModal(name, 'a', 9, 'Remove', 5, '#remove-resource-modal', '.bx--btn.bx--btn--tertiary')
   //re-entry overflow menu then click delete policy button (.bx--btn.bx--btn--danger--primary)
-  this.clickButtonOnOverflowModal(name, 'a', 9, 'Remove', 4, '#remove-resource-modal', '.bx--btn.bx--btn--danger--primary')
+  this.clickButtonOnOverflowModal(name, 'a', 9, 'Remove', 5, '#remove-resource-modal', '.bx--btn.bx--btn--danger--primary')
   this.waitForElementNotPresent('@spinner')
 }
 
-function clearSearchValue(){
-  this.isVisible('@searchInputClear', result => {
+function clearPatternFlySearchValue(){
+  this.waitForElementVisible('@searchPatternFlyInputClear')
+  this.isVisible('@searchPatternFlyInputClear', result => {
     if (result.value) {
-      this.click('@searchInputClear')
+      this.click('@searchPatternFlyInputClear')
     }
   })
-  this.waitForElementNotVisible('@searchInputClear')
+  this.waitForElementNotPresent('@searchPatternFlyInputClear')
 }
 
-function setSearchValue(value){
-  this.log(`Searching for policy: ${value}`)
-  this.clearSearchValue()
-  this.click('@searchInput').setValue('@searchInput', value)
+function testPolicyStatusTabSearching(){
+  this.log('Testing PatternFly tab searching bar on policy status tab message field')
+  this.api.getText('.policy-details-message', (result) => {
+    if (result && result.value ) {
+      // get policy status tab message field text
+      let policyStatusMessage = result.value
+      this.log(`searching text before truncate is ${policyStatusMessage}`)
+      if (typeof policyStatusMessage === 'string' && policyStatusMessage.length > 0) {
+        policyStatusMessage = policyStatusMessage.replace('View details', '')
+        this.log(`searching text after truncate is ${policyStatusMessage}`)
+        this.setPatternFlySearchValue(policyStatusMessage)
+        this.waitForElementNotPresent('@PatternFlyTabEmptyState')
+        this.clearPatternFlySearchValue()
+      }
+    }
+  })
+}
+
+function setPatternFlySearchValue(value){
+  this.log(`Searching for PatternFly table: ${value}`)
+  this.waitForElementVisible('@searchPatternFlyInput')
+  this.click('@searchPatternFlyInput').clearValue('@searchPatternFlyInput')
+  this.click('@searchPatternFlyInput').setValue('@searchPatternFlyInput', value)
+  this.waitForElementVisible('@searchPatternFlyInput')
 }
 
 function log(message) {
@@ -311,28 +329,28 @@ function tryEnable(name){
   this.log(`Enabling policy: ${name}`)
   //verify table/menu exist
   this.waitForElementVisible('body')
-  this.waitForElementVisible('@searchInput')
-  this.setSearchValue(name)
+  this.waitForElementVisible('@searchPatternFlyInput')
+  this.setPatternFlySearchValue(name)
   //verify cancel button (.bx--btn.bx--btn--secondary) on enable policy modal and return to main page
-  this.clickButtonOnOverflowModal(name, 'div:nth-child(1)', 9, 'Enable', 2, '#enable-resource-modal', '.bx--btn.bx--btn--secondary')
+  this.clickButtonOnOverflowModal(name, 'div:nth-child(1) > a', 9, 'Enable', 2, '#enable-resource-modal', '.bx--btn.bx--btn--secondary')
   //re-entry overflow menu then click enable policy button (.bx--btn.bx--btn--primary)
-  this.clickButtonOnOverflowModal(name, 'div:nth-child(1)', 9, 'Enable', 2, '#enable-resource-modal', '.bx--btn.bx--btn--primary')
-  this.waitForElementVisible('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra')
-  this.waitForElementNotPresent('#table-container .disabled-label')
-  this.clearSearchValue()
+  this.clickButtonOnOverflowModal(name, 'div:nth-child(1) > a', 9, 'Enable', 2, '#enable-resource-modal', '.bx--btn.bx--btn--primary')
+  this.waitForElementVisible('.pf-c-table')
+  this.waitForElementNotPresent('.pf-c-table .disabled-label')
+  this.clearPatternFlySearchValue()
 }
 
 function tryDisable(name){
   this.log(`Disabling policy: ${name}`)
   //verify table/menu exist
   this.waitForElementVisible('body')
-  this.waitForElementVisible('@searchInput')
-  this.setSearchValue(name)
+  this.waitForElementVisible('@searchPatternFlyInput')
+  this.setPatternFlySearchValue(name)
   //verify cancel button (.bx--btn.bx--btn--tertiary) on disable policy modal and return to main page
   this.clickButtonOnOverflowModal(name, 'a', 9, 'Disable', 2, '#disable-resource-modal', '.bx--btn.bx--btn--tertiary')
   //re-entry overflow menu then click delete policy button (.bx--btn.bx--btn--danger--primary)
   this.clickButtonOnOverflowModal(name, 'a', 9, 'Disable', 2, '#disable-resource-modal', '.bx--btn.bx--btn--danger--primary')
-  this.waitForElementVisible('table.bx--data-table-v2.resource-table.bx--data-table-v2--zebra')
-  this.waitForElementPresent('#table-container .disabled-label')
-  this.clearSearchValue()
+  this.waitForElementVisible('.pf-c-table')
+  this.waitForElementPresent('.pf-c-table .disabled-label')
+  this.clearPatternFlySearchValue()
 }
