@@ -1,10 +1,3 @@
-/**
- * Copyright IBM Corp. 2016, 2018
- *
- * This source code is licensed under the Apache-2.0 license found in the
- * LICENSE file in the root directory of this source tree.
- */
-
 /**
  * `createChainableTypeChecker` is used inside of our custom prop validators to
  * add in chaining `isRequired` on a given prop validator.
@@ -15,23 +8,22 @@ var createChainableTypeChecker = function createChainableTypeChecker(validate) {
     if (props[propName] == null) {
       if (isRequired) {
         if (props[propName] === null) {
-          return new Error("The ".concat(location, " `").concat(propName, "` is marked as required in ") + "".concat(componentName, ", but its value is `null`."));
+          return new Error("The " + location + " `" + propName + "` is marked as required in " + (componentName + ", but its value is `null`."));
         }
-
-        return new Error("The ".concat(location, " `").concat(propName, "` is marked as required in ") + "".concat(componentName, ", but its value is `undefined`."));
+        return new Error("The " + location + " `" + propName + "` is marked as required in " + (componentName + ", but its value is `undefined`."));
       }
-
       return null;
     } else {
       return validate(props, propName, componentName, location);
     }
-  }; // By default, the validator will have `isRequired` set to false. However, we
+  };
+
+  // By default, the validator will have `isRequired` set to false. However, we
   // also define the `isRequired` property on the validtor so that consumers can
   // chain their prop validator and assert that the property is required.
-
-
   var chainedCheckType = checkType.bind(null, false);
   chainedCheckType.isRequired = checkType.bind(null, true);
+
   return chainedCheckType;
 };
 
