@@ -604,8 +604,7 @@ module.exports = {
 		"7.2.4",
 		"7.3.0",
 		"7.3.1",
-		"7.3.2",
-		"7.3.3"
+		"7.3.2"
 	],
 	"79.0.3931.0": [
 		"8.0.0-beta.1",
@@ -712,8 +711,7 @@ module.exports = {
 	"80.0.3987.163": [
 		"8.2.1",
 		"8.2.2",
-		"8.2.3",
-		"8.5.3"
+		"8.2.3"
 	],
 	"80.0.3987.165": [
 		"8.2.4",
@@ -725,9 +723,7 @@ module.exports = {
 		"8.3.4",
 		"8.4.0",
 		"8.4.1",
-		"8.5.0",
-		"8.5.1",
-		"8.5.2"
+		"8.5.0"
 	],
 	"82.0.4048.0": [
 		"9.0.0-beta.1",
@@ -841,12 +837,7 @@ module.exports = {
 		"9.1.1",
 		"9.1.2",
 		"9.2.0",
-		"9.2.1",
-		"9.3.0",
-		"9.3.1",
-		"9.3.2",
-		"9.3.3",
-		"9.3.4"
+		"9.2.1"
 	],
 	"84.0.4129.0": [
 		"10.0.0-beta.1",
@@ -898,12 +889,6 @@ module.exports = {
 	"85.0.4183.70": [
 		"10.0.0-beta.23"
 	],
-	"85.0.4183.78": [
-		"10.0.0-beta.24"
-	],
-	"85.0.4183.80": [
-		"10.0.0-beta.25"
-	],
 	"82.0.4050.0": [
 		"10.0.0-nightly.20200209",
 		"10.0.0-nightly.20200210",
@@ -969,64 +954,6 @@ module.exports = {
 		"10.0.0-nightly.20200429",
 		"10.0.0-nightly.20200430"
 	],
-	"85.0.4183.84": [
-		"10.0.0"
-	],
-	"85.0.4183.86": [
-		"10.0.1"
-	],
-	"85.0.4183.87": [
-		"10.1.0"
-	],
-	"85.0.4183.93": [
-		"10.1.1"
-	],
-	"85.0.4183.98": [
-		"10.1.2"
-	],
-	"85.0.4183.121": [
-		"10.1.3",
-		"10.1.4",
-		"10.1.5"
-	],
-	"86.0.4234.0": [
-		"11.0.0-beta.1",
-		"11.0.0-beta.3",
-		"11.0.0-beta.4",
-		"11.0.0-beta.5",
-		"11.0.0-beta.6",
-		"11.0.0-beta.7",
-		"11.0.0-nightly.20200822",
-		"11.0.0-nightly.20200824",
-		"11.0.0-nightly.20200825",
-		"11.0.0-nightly.20200826",
-		"12.0.0-nightly.20200827",
-		"12.0.0-nightly.20200831",
-		"12.0.0-nightly.20200902",
-		"12.0.0-nightly.20200903",
-		"12.0.0-nightly.20200907",
-		"12.0.0-nightly.20200910",
-		"12.0.0-nightly.20200911",
-		"12.0.0-nightly.20200914"
-	],
-	"87.0.4251.1": [
-		"11.0.0-beta.8",
-		"11.0.0-beta.9",
-		"11.0.0-beta.11"
-	],
-	"87.0.4280.11": [
-		"11.0.0-beta.12",
-		"11.0.0-beta.13"
-	],
-	"87.0.4280.27": [
-		"11.0.0-beta.16",
-		"11.0.0-beta.17",
-		"11.0.0-beta.18",
-		"11.0.0-beta.19"
-	],
-	"87.0.4280.40": [
-		"11.0.0-beta.20"
-	],
 	"85.0.4156.0": [
 		"11.0.0-nightly.20200529"
 	],
@@ -1069,24 +996,5 @@ module.exports = {
 		"11.0.0-nightly.20200805",
 		"11.0.0-nightly.20200811",
 		"11.0.0-nightly.20200812"
-	],
-	"87.0.4268.0": [
-		"12.0.0-nightly.20201013",
-		"12.0.0-nightly.20201014",
-		"12.0.0-nightly.20201015"
-	],
-	"88.0.4292.0": [
-		"12.0.0-nightly.20201023",
-		"12.0.0-nightly.20201026"
-	],
-	"88.0.4306.0": [
-		"12.0.0-nightly.20201030",
-		"12.0.0-nightly.20201102",
-		"12.0.0-nightly.20201103",
-		"12.0.0-nightly.20201104",
-		"12.0.0-nightly.20201105",
-		"12.0.0-nightly.20201106",
-		"12.0.0-nightly.20201111",
-		"12.0.0-nightly.20201112"
 	]
 };
\ No newline at end of file
